Feel free to contact me at [zain.eris.kamal@rutgers.edu](mailto:zain.eris.kamal@rutgers.edu). I'm more than happy to take any questions, discussion, feedback, or criticism. I also welcome any requests to share/explain code or help adapt it for your purposes.

You can see more of my work here: [github.com/humboldt-penguin](https://github.com/humboldt-penguin/){target="_blank"}.

Huge thanks to my incredible advisor [Prof. Lujendra Ojha](https://www.lujendraojha.com/){target="_blank"} for all his support, guidance, patience, and kindness over the past four years.
